using Microsoft.EntityFrameworkCore;
using assignment2.Models;

public class ExperienceDBContext : DbContext
{
    private readonly string connString = Environment.GetEnvironmentVariable("DATABASE_CONNECTION_STRING") ?? "Host=localhost;Port=5432;Database=experience;Username=postgres;Password=postgres";
    public ExperienceDBContext(DbContextOptions<ExperienceDBContext> options) : base(options)
    {
    }

    public DbSet<Experience> Experiences { get; set; }
    public DbSet<SharedExperience> SharedExperiences { get; set; }
    public DbSet<Provider> Providers { get; set; }
    public DbSet<Discount> Discounts { get; set; }
    public DbSet<Guest> Guests { get; set; }

    protected override void OnConfiguring(DbContextOptionsBuilder optionsBuilder)
    {
        optionsBuilder.UseSqlServer(connString);
    }

    protected override void OnModelCreating(ModelBuilder modelBuilder)
    {
        modelBuilder.Entity<SharedExperience>(se =>
        {
            se.HasMany(se => se.Experiences)
            .WithMany(e => e.SharedExperiences)
            .UsingEntity(t => t.ToTable("SharedExperiencesExperiences"));
        });

        modelBuilder.Entity<Guest>(g =>
        {
            g.HasMany(g => g.Experiences)
            .WithMany(e => e.Guests)
            .UsingEntity(t => t.ToTable("GuestsExperiences"));
        });

        modelBuilder.Entity<Guest> (g=>
        {
            g.HasMany(g => g.SharedExperiences)
            .WithMany(se => se.Guests)
            .UsingEntity(t => t.ToTable("GuestsSharedExperiences"));
        });
    }
}