using assignment2.Models;
using Bogus;

public class Seeder
{
    private readonly ExperienceDBContext _context;
    public Seeder(ExperienceDBContext context)
    {
        _context = context;
    }

    public void SeedData()
    {
        _context.Database.EnsureCreated();

        if (_context.Experiences.Any())
        {
            Console.WriteLine("Database already has data. Skipping seeding...");
            return;
        }

        Console.WriteLine("Seeding database with Bogus data...");
        
        var guestFaker = new Faker<Guest>()
            .RuleFor(g => g.Name, f => f.Name.FullName())
            .RuleFor(g => g.Age, f => f.Random.Int(18, 99))
            .RuleFor(g => g.Phone, f => f.Random.Int(111111, 999999));

        var guests = guestFaker.Generate(10);

        var experienceFaker = new Faker<Experience>()
            .RuleFor(e => e.Name, f => f.Commerce.ProductName())
            .RuleFor(e => e.Description, f => f.Lorem.Sentence())
            .RuleFor(e => e.Price, f => (decimal)(f.Random.Int(50, 2000)))
            .RuleFor(e => e.Provider, f => new Provider
            {
                Name = f.Company.CompanyName(),
                Address = f.Address.FullAddress(),
                Phone = f.Phone.PhoneNumber(),
                CVR = f.Random.Replace("########")
            })
            .RuleFor(e => e.Guests, f => f.PickRandom(guests, 5).ToList());

        var experiences = experienceFaker.Generate(10);

        var sharedFaker = new Faker<SharedExperience>()
            .RuleFor(se => se.Description, f => f.Commerce.ProductName())
            .RuleFor(se => se.Date, f => f.Date.Between(DateTime.Now.AddYears(-1), DateTime.Now))
            .RuleFor(se => se.Experiences, f => f.PickRandom(experiences, 3).ToList())
            .RuleFor(se => se.Guests, f => f.PickRandom(guests, 4).ToList());

        var sharedExperiences = sharedFaker.Generate(10);

        _context.Experiences.AddRange(experiences);
        _context.Guests.AddRange(guests);
        _context.SharedExperiences.AddRange(sharedExperiences);
        _context.SaveChanges();

        Console.WriteLine("Database seeding completed.");
    }
}
