using assignment1.Interfaces;
using assignment1.Services;
using DotNetEnv;
using assignment2.Controllers;
using assignment2.Services;
using assignment2.Models;
var builder = WebApplication.CreateBuilder(args);

// Add services to the container.
builder.Services.AddControllers();

//Inject the Services
builder.Services.AddTransient<IExperienceService, ExperienceService>();
builder.Services.AddTransient<IProviderService, ProviderService>();
builder.Services.AddTransient<ISharedExperienceService, SharedExperienceService>();
builder.Services.AddTransient<IGuestService, GuestService>();
Env.Load();
builder.Services.AddDbContext<ExperienceDBContext>();


// Enable Swagger/OpenAPI
builder.Services.AddEndpointsApiExplorer();
builder.Services.AddSwaggerGen(options =>
{
    options.SwaggerDoc("v1", new Microsoft.OpenApi.Models.OpenApiInfo
    {
        Title = "Experience API",
        Version = "v1",
        Description = "An API to manage experiences",
        Contact = new Microsoft.OpenApi.Models.OpenApiContact
        {
            Name = "Vores awesome api",
        }
    });
});

var app = builder.Build();

// Seed the database (from lessson)
using (var scope = app.Services.CreateScope())
{
    var context = scope.ServiceProvider.GetRequiredService<ExperienceDBContext>();
    var seeder = new Seeder(context);
    seeder.SeedData();
}

// Configure the HTTP request pipeline.
app.UseSwagger();
app.UseSwaggerUI(c =>
{
    c.SwaggerEndpoint("/swagger/v1/swagger.json", "Experience API v1");
    c.RoutePrefix = ""; // Swagger loads at the root URL
});

// Conditionally handle HTTPS redirection based on environment
app.UseAuthorization();
app.MapControllers();
app.Run();
