
using Microsoft.EntityFrameworkCore;

public class ExperienceService : IExperienceService
{
    private readonly ExperienceDBContext context;

    public ExperienceService(ExperienceDBContext context)
    {
        this.context = context;
    }
    public async Task<IEnumerable<ExperienceView>> GetExperiences()
    {
        var res = await context.Experiences.ToListAsync();
        return res.ToExperienceView();
    }

    public async Task<ExperienceView> GetExperience(string name)
    {
        var res = await context.Experiences.FirstOrDefaultAsync(e => e.Name == name);
        if (res == null)
        {
            return null;
        }
        return res.ToExperienceView();
    }

    public async Task<Statistics> GetStatistics()
    {
        var experiences = await context.Experiences.ToListAsync();
        if (experiences == null)
        {
            return null;
        }

        var stats = new Statistics
        {
            MaxPrice = experiences.Max(e => e.Price),
            MinPrice = experiences.Min(e => e.Price),
            AveragePrice = experiences.Average(e => e.Price)
        };
        return stats;
    }

    public async Task<IEnumerable<ExperienceSalesView>> GetSales()
    {
        var res = await context.Experiences
            .Include(e => e.Guests)
            .Select(e => new ExperienceSalesView
            {
                Name = e.Name,
                GuestCount = e.Guests.Count,
                TotalPrice = e.Price * e.Guests.Count
            })
            .ToListAsync();
        return res;
    }
}