﻿using assignment1.DTO;
using assignment1.Interfaces;
using assignment2.Models;
using Microsoft.AspNetCore.Mvc;
using Microsoft.EntityFrameworkCore;
using Microsoft.Identity.Client;
using Sprache;
using System.Collections;

namespace assignment1.Services
{
    public class SharedExperienceService : ISharedExperienceService
    {
        private readonly ExperienceDBContext _experienceDBContext;
        private readonly IExperienceService _experienceService;

        public SharedExperienceService(ExperienceDBContext experienceDBContext, IExperienceService experienceService)
        {
            _experienceDBContext = experienceDBContext;
            _experienceService = experienceService;
        }

        public async Task<IEnumerable<SharedExperienceView>> GetAll()
        {
            return await _experienceDBContext.SharedExperiences
                .Select(e => e.ToSharedExperienceView())
                .ToListAsync();
        }
        
        public async Task<IEnumerable<GuestView>> GetGuests(int id)
        {
            var sharedExperience = await _experienceDBContext.SharedExperiences
                .Include(se => se.Guests)
                .FirstAsync(se => se.SharedExperienceId == id);
            return sharedExperience?.Guests.Select(e => new GuestView { Name = e.Name }).ToList() ?? new List<GuestView>();
        }

        public async Task<IEnumerable<ExperienceView>> GetExperiences(int id)
        {
            var sharedExperience = await _experienceDBContext.SharedExperiences
                .Include(se => se.Experiences)
                .FirstAsync(se => se.SharedExperienceId == id);

            if (sharedExperience.Experiences == null)
            {
                return new List<ExperienceView>();  
            }

            return sharedExperience.Experiences.Select(e => e.ToExperienceView()) ?? new List<ExperienceView>();
        }

        public async Task<IEnumerable<GuestView>> GetGuestsInExperience(int id, int experienceId)
        {
            var sharedExperience = await _experienceDBContext.SharedExperiences
                .Include(se => se.Guests)
                .Include(se => se.Experiences!)
                .ThenInclude(e => e.Guests!)
                .FirstAsync(se => se.SharedExperienceId == id);
            
            if(sharedExperience.Experiences == null)
            {
                return new List<GuestView>();
            }

            var experience = sharedExperience.Experiences.FirstOrDefault(e => e.ExperienceId == experienceId);

            if (experience == null)
            {
                return new List<GuestView>();
            }

            var guestsInExperience = experience
                .Guests?
                .Where(g => sharedExperience.Guests.Contains(g))
                .ToList() ?? new List<Guest>();
            return guestsInExperience
                .Select(g => new GuestView { Name = g.Name })
                .ToList();
        }
    }
}
